#!/usr/bin/env python3

import shlex
import radical.pilot as rp
from radical.pilot.task_description import NAMED_ENV


# ------------------------------------------------------------------------------
#
if __name__ == '__main__':

    session = rp.Session()

    try:
        pmgr  = rp.PilotManager(session=session)
        pdesc = rp.PilotDescription({'resource': 'local.localhost',
                                     'runtime' : 60,
                                     'cores'   : 64})
        pilot = pmgr.submit_pilots(pdesc)


        pilot.prepare_env({
                'scalems_env': {
                    'type': 'virtualenv',
                    'version': '3.8',
                    'setup': [
        'radical.pilot@git+https://github.com/radical-cybertools/radical.pilot.git@project/scalems',
        'scalems@git+https://github.com/SCALE-MS/scale-ms.git@sms-54'
        ]}})

        tmgr  = rp.TaskManager(session=session)

        tmgr.add_pilots(pilot)

        td    = rp.TaskDescription({'executable': 'python3',
                                    'arguments' : ['-c',
                                                   'import radical.pilot as rp;'
                                                   'import scalems;'
                                                   'print(rp.version_detail);'
                                                   'print(scalems.__file__)'],
                                    'named_env' : 'scalems_env'})
        task  = tmgr.submit_tasks(td)
        tmgr.wait_tasks()

        print(task.stdout)

    finally:
        session.close(download=False)


# ------------------------------------------------------------------------------




#!/usr/bin/env python3

from radical.entk import Pipeline, Stage, Task, AppManager
import os

host = os.environ.get('RMQ_HOSTNAME', 'localhost')
port = int(os.environ.get('RMQ_PORT', 5672))


def generate_pipeline():

    p = Pipeline()
    s = Stage()
    t = Task()
    t.executable = '/bin/date'
    t.cpu_reqs   = {'processes'           : 6,
                    'process_type'        : 'MPI',
                    'threads_per_process' : 1,
                    'thread_type'         : 'OpenMP'}
    t.gpu_reqs   = {'processes'           : 1,
                    'process_type'        : 'MPI',
                    'threads_per_process' : 1,
                    'thread_type'         : 'CUDA'}
    s.add_tasks(t)
    p.add_stages(s)

    return p


if __name__ == '__main__':

    appman   = AppManager(hostname=host, port=port)
    res_dict = {
        'resource': 'local.traverse',
        'walltime': 10,
        'cpus'    : 64,
        'gpus'    :  8
    }

    appman.resource_desc = res_dict
    appman.workflow = set([generate_pipeline()])
    appman.run()



#!/usr/bin/env python

import os
import random

rand = random.choice

import radical.pilot as rp


# ------------------------------------------------------------------------------
#
if __name__ == '__main__':

    with rp.Session() as session:

        pmgr    = rp.PilotManager(session=session)
        pd_init = {'resource'      : 'local.scale',
                   'runtime'       : 60,
                   'exit_on_error' : True,
                   'cores'         : 1024 * 8
                  }
        pdesc = rp.ComputePilotDescription(pd_init)
        pilot = pmgr.submit_pilots(pdesc)
        umgr  = rp.UnitManager(session=session)
        umgr.add_pilots(pilot)

        n    = 1024 * 2
        cuds = list()
        for i in range(0, n):

            cud = rp.ComputeUnitDescription()
            cud.executable       = '%s/examples/hello_rp.sh' % os.getcwd()
            cud.arguments        = [rand([1, 2, 4, 8, 16, 32]) * 4]
            cud.gpu_processes    =  rand([0, 0, 0, 0, 0, 1, 1, 2])
            cud.cpu_processes    =  rand([1, 2, 4, 8, 16, 32] * 1)
            cud.cpu_threads      =  rand([1, 2, 4])
            cud.gpu_process_type = rp.MPI
            cud.cpu_process_type = rp.MPI
            cud.cpu_thread_type  = rp.OpenMP
            cuds.append(cud)

        umgr.submit_units(cuds)
        umgr.wait_units()


# ------------------------------------------------------------------------------

